==> koffice-trinity_14.0.13.orig.tar.xz: koffice-trinity-14.0.13/kword/mailmerge/sql/KWMySqlCursor.h <==
/* This file is part of the KDE project
   Copyright (C) 2001 Joseph Wenninger <jowenn@kde.org>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
*/

#ifndef _SERIALLETTER_QtSql_SQLCURSOR_H_
#define _SERIALLETTER_QtSql_SQLCURSOR_H_

/* FOR THE DIRTY HACK */
#include <tqsqlcursor.h>
#include <tqsqldriver.h>
/* END FOR THE DIRTY HACK */

/******************************************************************
 *
 * DIRTY HACK FOR SOME INFLEXIBILITY IN QT3's SQL stuff
 *
 * This class is rom some Trolltech guy on QT-interest
 ******************************************************************/



class KWMySqlCursor: public TQSqlCursor
{
public:
    KWMySqlCursor( const TQString & query = TQString(), bool autopopulate = 
TRUE, TQSqlDatabase* db = 0 ): TQSqlCursor( TQString(), autopopulate, db )
    {
        exec( query );
        if ( autopopulate )
            *(TQSqlRecord*)this = ((TQSqlQuery*)this)->driver()->record(
*(TQSqlQuery*)this );
        setMode( TQSqlCursor::ReadOnly );
    }
    KWMySqlCursor( const KWMySqlCursor & other ): TQSqlCursor( other ) {}
    KWMySqlCursor( const TQSqlQuery & query, bool autopopulate = TRUE ): 
TQSqlCursor( TQString(), autopopulate )
    {
        *(TQSqlQuery*)this = query;
        if ( autopopulate )
            *(TQSqlRecord*)this = query.driver()->record( query );
        setMode( TQSqlCursor::ReadOnly );
    }
    bool select( const TQString & /*filter*/, const TQSqlIndex & /*sort*/ = 
TQSqlIndex() ) { return exec( lastQuery() ); }
    TQSqlIndex primaryIndex( bool /*prime*/ = TRUE ) const { return
TQSqlIndex(); }
    int insert( bool /*invalidate*/ = TRUE ) { return FALSE; }
    int update( bool /*invalidate*/ = TRUE ) { return FALSE; }
    int del( bool /*invalidate*/ = TRUE ) { return FALSE; }
    void setName( const TQString& /*name*/, bool /*autopopulate*/ = TRUE ) {}
};


#endif

==> koffice-trinity_14.1.3.orig.tar.xz: koffice-trinity-14.1.3/kword/mailmerge/sql/KWMySqlCursor.h <==
/* This file is part of the KDE project
   Copyright (C) 2001 Joseph Wenninger <jowenn@kde.org>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
*/

#ifndef _SERIALLETTER_QtSql_SQLCURSOR_H_
#define _SERIALLETTER_QtSql_SQLCURSOR_H_

/* FOR THE DIRTY HACK */
#include <tqsqlcursor.h>
#include <tqsqldriver.h>
/* END FOR THE DIRTY HACK */

/******************************************************************
 *
 * DIRTY HACK FOR SOME INFLEXIBILITY IN QT3's SQL stuff
 *
 * This class is from some Trolltech guy on QT-interest
 ******************************************************************/



class KWMySqlCursor: public TQSqlCursor
{
public:
    KWMySqlCursor( const TQString & query = TQString(), bool autopopulate = 
TRUE, TQSqlDatabase* db = 0 ): TQSqlCursor( TQString(), autopopulate, db )
    {
        exec( query );
        if ( autopopulate )
            *(TQSqlRecord*)this = ((TQSqlQuery*)this)->driver()->record(
*(TQSqlQuery*)this );
        setMode( TQSqlCursor::ReadOnly );
    }
    KWMySqlCursor( const KWMySqlCursor & other ): TQSqlCursor( other ) {}
    KWMySqlCursor( const TQSqlQuery & query, bool autopopulate = TRUE ): 
TQSqlCursor( TQString(), autopopulate )
    {
        *(TQSqlQuery*)this = query;
        if ( autopopulate )
            *(TQSqlRecord*)this = query.driver()->record( query );
        setMode( TQSqlCursor::ReadOnly );
    }
    bool select( const TQString & /*filter*/, const TQSqlIndex & /*sort*/ = 
TQSqlIndex() ) { return exec( lastQuery() ); }
    TQSqlIndex primaryIndex( bool /*prime*/ = TRUE ) const { return
TQSqlIndex(); }
    int insert( bool /*invalidate*/ = TRUE ) { return FALSE; }
    int update( bool /*invalidate*/ = TRUE ) { return FALSE; }
    int del( bool /*invalidate*/ = TRUE ) { return FALSE; }
    void setName( const TQString& /*name*/, bool /*autopopulate*/ = TRUE ) {}
};


#endif
